HttpTransparencyLogClient

Struct HttpTransparencyLogClient 

pub struct HttpTransparencyLogClient { /* private fields */ }
HTTP-based Transparency Log client.

Implementations

Source

impl HttpTransparencyLogClient

pub fn new() -> Self

Create a new client with default settings.

pub fn with_base_url(base_url: impl AsRef<str>) -> Result<Self, TlogError>

Create a new client with a base URL for agent ID lookups.

Errors

Returns TlogError::InvalidUrl if the URL cannot be parsed.

pub fn with_timeout(self, timeout: Duration) -> Self

Set the request timeout.

pub fn with_header( self, name: impl Into<String>, value: impl Into<String>, ) -> Self

Add a custom header to include with every request.

Invalid header names or values will cause an error when making requests.

pub fn with_headers( self, headers: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>, ) -> Self

Add multiple custom headers to include with every request.

Invalid header names or values will cause an error when making requests.