TransparencyLogClient

Trait TransparencyLogClient 

pub trait TransparencyLogClient: Send + Sync {
    // Required methods
    fn fetch_badge<'life0, 'life1, 'async_trait>(
        &'life0 self,
        url: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Badge, TlogError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn fetch_badge_by_id<'life0, 'async_trait>(
        &'life0 self,
        agent_id: Uuid,
    ) -> Pin<Box<dyn Future<Output = Result<Badge, TlogError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn fetch_audit<'life0, 'async_trait>(
        &'life0 self,
        agent_id: Uuid,
        limit: Option<u32>,
        offset: Option<u32>,
    ) -> Pin<Box<dyn Future<Output = Result<AuditResponse, TlogError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Transparency Log API client trait.

Required Methods

fn fetch_badge<'life0, 'life1, 'async_trait>( &'life0 self, url: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Badge, TlogError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Fetch a badge by its full URL.

fn fetch_badge_by_id<'life0, 'async_trait>( &'life0 self, agent_id: Uuid, ) -> Pin<Box<dyn Future<Output = Result<Badge, TlogError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Fetch a badge by agent ID.

fn fetch_audit<'life0, 'async_trait>( &'life0 self, agent_id: Uuid, limit: Option<u32>, offset: Option<u32>, ) -> Pin<Box<dyn Future<Output = Result<AuditResponse, TlogError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Fetch the audit trail for an agent.

Returns a paginated list of all transparency log entries for the agent, providing a complete audit history of registration events.

Implementors