pub struct HttpTransparencyLogClient { /* private fields */ }Expand description
HTTP-based Transparency Log client.
Implementations
Sourceimpl HttpTransparencyLogClient
impl HttpTransparencyLogClient
Sourcepub fn with_base_url(base_url: impl AsRef<str>) -> Result<Self, TlogError>
pub fn with_base_url(base_url: impl AsRef<str>) -> Result<Self, TlogError>
Create a new client with a base URL for agent ID lookups.
Errors
Returns TlogError::InvalidUrl if the URL cannot be parsed.
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Set the request timeout.
Sourcepub fn with_header(
self,
name: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn with_header( self, name: impl Into<String>, value: impl Into<String>, ) -> Self
Add a custom header to include with every request.
Invalid header names or values will cause an error when making requests.
Sourcepub fn with_headers(
self,
headers: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>,
) -> Self
pub fn with_headers( self, headers: impl IntoIterator<Item = (impl Into<String>, impl Into<String>)>, ) -> Self
Add multiple custom headers to include with every request.
Invalid header names or values will cause an error when making requests.